@@ -1,12 +1,15 @@
-import os, sys, pygame
-from originator import *
-from careTaker import *
-from orientation import *
+import os, sys
+import pygame
+from .originator import *
+from .careTaker import *
+from .orientation import *
+
 from random import randint
 import pkg_resources
 
 class Agent:
     def __init__(self, name, begin, end, color):
+        self.test = Test()
         self._name = name
         self.orientation = Orientation.NORTH
         self.num = id(self)
@@ -16,7 +19,7 @@ class Agent:
         self.originator = Originator()
         self.caretaker = CareTaker()
         self.position = None
-        path = pkg_resources.resource_filename(__name__, "../data/images/turtle_small.png")
+        path = pkg_resources.resource_filename(__name__, "data/images/turtle_small.png")
         self.turtle = pygame.image.load(path)
         self.angle = 0
 
